@@ -3,6 +3,8 @@
 #
 # 0.01	R. Boisvert	8/6/2013
 # First release.
+# 0.02	R. Boisvert	8/6/2013
+# Fixed bugs caused by PerlCritic adjustments.
 ##########
 
 package Win32::LongPath;
@@ -14,7 +16,6 @@ use warnings;
 
 use Carp;
 require Encode;
-require Exporter;
 use Fcntl qw(O_RDONLY O_RDWR O_WRONLY O_APPEND :mode);
 use File::Spec::Functions;
 use Time::Local;
@@ -23,49 +24,49 @@ use Time::Local;
 # external constants
 ##########
 
-sub FILE_ATTRIBUTE_ARCHIVE {0x20}
-sub FILE_ATTRIBUTE_COMPRESSED {0x800}
-sub FILE_ATTRIBUTE_DEVICE {0x40}
-sub FILE_ATTRIBUTE_DIRECTORY {0x10}
-sub FILE_ATTRIBUTE_ENCRYPTED {0x4000}
-sub FILE_ATTRIBUTE_HIDDEN {0x2}
-sub FILE_ATTRIBUTE_INTEGRITY_STREAM {0x8000}
-sub FILE_ATTRIBUTE_NORMAL {0x80}
-sub FILE_ATTRIBUTE_NOT_CONTENT_INDEXED {0x2000}
-sub FILE_ATTRIBUTE_NO_SCRUB_DATA {0x20000}
-sub FILE_ATTRIBUTE_OFFLINE {0x1000}
-sub FILE_ATTRIBUTE_READONLY {0x1}
-sub FILE_ATTRIBUTE_REPARSE_POINT {0x400}
-sub FILE_ATTRIBUTE_SPARSE_FILE {0x200}
-sub FILE_ATTRIBUTE_SYSTEM {0x4}
-sub FILE_ATTRIBUTE_TEMPORARY {0x100}
-sub FILE_ATTRIBUTE_VIRTUAL {0x10000}
+sub FILE_ATTRIBUTE_ARCHIVE () {0x20}
+sub FILE_ATTRIBUTE_COMPRESSED () {0x800}
+sub FILE_ATTRIBUTE_DEVICE () {0x40}
+sub FILE_ATTRIBUTE_DIRECTORY () {0x10}
+sub FILE_ATTRIBUTE_ENCRYPTED () {0x4000}
+sub FILE_ATTRIBUTE_HIDDEN () {0x2}
+sub FILE_ATTRIBUTE_INTEGRITY_STREAM () {0x8000}
+sub FILE_ATTRIBUTE_NORMAL () {0x80}
+sub FILE_ATTRIBUTE_NOT_CONTENT_INDEXED () {0x2000}
+sub FILE_ATTRIBUTE_NO_SCRUB_DATA () {0x20000}
+sub FILE_ATTRIBUTE_OFFLINE () {0x1000}
+sub FILE_ATTRIBUTE_READONLY () {0x1}
+sub FILE_ATTRIBUTE_REPARSE_POINT () {0x400}
+sub FILE_ATTRIBUTE_SPARSE_FILE () {0x200}
+sub FILE_ATTRIBUTE_SYSTEM () {0x4}
+sub FILE_ATTRIBUTE_TEMPORARY () {0x100}
+sub FILE_ATTRIBUTE_VIRTUAL () {0x10000}
 
-sub FILE_CASE_PRESERVED_NAMES {0x00000002}
-sub FILE_CASE_SENSITIVE_SEARCH {0x00000001}
-sub FILE_FILE_COMPRESSION {0x00000010}
-sub FILE_NAMED_STREAMS {0x00040000}
-sub FILE_PERSISTENT_ACLS {0x00000008}
-sub FILE_READ_ONLY_VOLUME {0x00080000}
-sub FILE_SEQUENTIAL_WRITE_ONCE {0x00100000}
-sub FILE_SUPPORTS_ENCRYPTION {0x00020000}
-sub FILE_SUPPORTS_EXTENDED_ATTRIBUTES {0x00800000}
-sub FILE_SUPPORTS_HARD_LINKS {0x00400000}
-sub FILE_SUPPORTS_OBJECT_IDS {0x00010000}
-sub FILE_SUPPORTS_OPEN_BY_FILE_ID {0x01000000}
-sub FILE_SUPPORTS_REPARSE_POINTS {0x00000080}
-sub FILE_SUPPORTS_SPARSE_FILES {0x00000040}
-sub FILE_SUPPORTS_TRANSACTIONS {0x00200000}
-sub FILE_SUPPORTS_USN_JOURNAL {0x02000000}
-sub FILE_UNICODE_ON_DISK {0x00000004}
-sub FILE_VOLUME_IS_COMPRESSED {0x00008000}
-sub FILE_VOLUME_QUOTAS {0x00000020}
+sub FILE_CASE_PRESERVED_NAMES () {0x00000002}
+sub FILE_CASE_SENSITIVE_SEARCH () {0x00000001}
+sub FILE_FILE_COMPRESSION () {0x00000010}
+sub FILE_NAMED_STREAMS () {0x00040000}
+sub FILE_PERSISTENT_ACLS () {0x00000008}
+sub FILE_READ_ONLY_VOLUME () {0x00080000}
+sub FILE_SEQUENTIAL_WRITE_ONCE () {0x00100000}
+sub FILE_SUPPORTS_ENCRYPTION () {0x00020000}
+sub FILE_SUPPORTS_EXTENDED_ATTRIBUTES () {0x00800000}
+sub FILE_SUPPORTS_HARD_LINKS () {0x00400000}
+sub FILE_SUPPORTS_OBJECT_IDS () {0x00010000}
+sub FILE_SUPPORTS_OPEN_BY_FILE_ID () {0x01000000}
+sub FILE_SUPPORTS_REPARSE_POINTS () {0x00000080}
+sub FILE_SUPPORTS_SPARSE_FILES () {0x00000040}
+sub FILE_SUPPORTS_TRANSACTIONS () {0x00200000}
+sub FILE_SUPPORTS_USN_JOURNAL () {0x02000000}
+sub FILE_UNICODE_ON_DISK () {0x00000004}
+sub FILE_VOLUME_IS_COMPRESSED () {0x00008000}
+sub FILE_VOLUME_QUOTAS () {0x00000020}
 
 ##########
 # exports
 ##########
 
-our (@EXPORT_OK, %EXPORT_TAGS, $VERSION);
+our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS, $VERSION);
 BEGIN
   {
   my @aFuncs =
@@ -112,14 +113,15 @@ BEGIN
     FILE_VOLUME_IS_COMPRESSED
     FILE_VOLUME_QUOTAS
     );
+  @EXPORT = @aFuncs;
   @EXPORT_OK = (@aAttribs, @aVolFlags);
   %EXPORT_TAGS = (
-    all => [@aFuncs, @EXPORT_OK],
+    all => [@EXPORT, @EXPORT_OK],
     funcs => [@aFuncs],
     fileattr => [@aAttribs],
     volflags => [@aVolFlags]
     );
-  $VERSION = '0.01';
+  $VERSION = '0.02';
   require XSLoader;
   XSLoader::load ('Win32::LongPath', $VERSION);
   }
